@@ -201,7 +201,7 @@ const char** InitializeSynopsis(void)
     // Movie and multimedia handling functions:
     synopsis[i++] = "\n% Movie and multimedia playback functions:";
     synopsis[i++] =  "[ moviePtr [duration] [fps] [width] [height] [count] [aspectRatio]]=Screen('OpenMovie', windowPtr, moviefile [, async=0] [, preloadSecs=1] [, specialFlags1=0][, pixelFormat=4][, maxNumberThreads=-1][, movieOptions]);";
-    synopsis[i++] =  "Screen('CloseMovie', moviePtr);";
+    synopsis[i++] =  "Screen('CloseMovie' [, moviePtr=all]);";
     synopsis[i++] =  "[ texturePtr [timeindex]]=Screen('GetMovieImage', windowPtr, moviePtr, [waitForImage], [fortimeindex], [specialFlags = 0] [, specialFlags2 = 0]);";
     synopsis[i++] =  "[droppedframes] = Screen('PlayMovie', moviePtr, rate, [loop], [soundvolume]);";
     synopsis[i++] =  "timeindex = Screen('GetMovieTimeIndex', moviePtr);";
