@@ -26,11 +26,28 @@ function err = Snd(command,signal,rate,sampleSize)
 % implementations of Matlab. There are many bugs, latency- and timing
 % problems associated with the use of Snd.
 %
-% GNU/OCTAVE: If you don't use the PsychPortAudio based Snd() functin, then
+% GNU/OCTAVE: If you don't use the PsychPortAudio based Snd() function, then
 % you must install the optional octave "audio" package from Octave-Forge,
 % as of Octave 3.0.5, otherwise the required sound() function won't be
 % available and this function will fail!
 %
+% Audio device sharing for interop with PsychPortAudio:
+% -----------------------------------------------------
+%
+% If you want to use PsychPortAudio and Snd() simultaneously (or one of the
+% functions that indirectly use Snd(), e.g., Beeper() for simple beep tones,
+% or Eyelink's auditory feedback during tracker setup and recalibration, which
+% in turn uses Beeper() and thereby Snd(), then try this:
+%
+% 1. Open a suitable PsychPortAudio audio device, possibly also a slave audio
+%    device and get a pahandle to it, e.g., pahandle = PsychPortAudio('Open',...);
+%
+% 2. Now open Snd(), passing in this device handle for use as Snd() output device:
+%    Snd('Open', pahandle);
+%
+% 3. Proceed as usual, e.g., Snd('Play', ...) or Beeper(...), etc. Snd() will
+%    use the pahandle audio device for playback, and pahandle can also be used
+%    by PsychPortAudio calls directly for precisely controlled sound.
 %
 % Supported functions:
 % --------------------
@@ -53,8 +70,9 @@ function err = Snd(command,signal,rate,sampleSize)
 %
 % Snd('Open') opens the channel, which stays open until you call
 % Snd('Close'). Snd('Play',...) automatically opens the channel if it isn't
-% already open. In reality 'Open' does nothing in the current
-% implementation and is silently ignored .
+% already open. You can use Snd('Open', pahandle); to share an existing
+% PsychPortAudio audio device handle 'pahandle' with Snd() for optimal
+% interoperation. See instructions above.
 %
 % Snd('Close') immediately stops all sound and closes the channel.
 %
@@ -112,19 +130,19 @@ function err = Snd(command,signal,rate,sampleSize)
 %
 % See also PsychPortAudio, Beeper, AUDIOPLAYER, PLAY, MakeBeep, READSND, and WRITESND.
 
-% 6/6/96	dgp Wrote SndPlay.
-% 6/1/97	dgp Polished help text.
-% 12/10/97	dhb Updated help.
-% 2/4/98	dgp Wrote Snd, based on major update of VideoToolbox SndPlay1.c.
+% 6/6/96    dgp Wrote SndPlay.
+% 6/1/97    dgp Polished help text.
+% 12/10/97  dhb Updated help.
+% 2/4/98    dgp Wrote Snd, based on major update of VideoToolbox SndPlay1.c.
 % 3/8/00    emw Added PC notes and code.
 % 7/23/00   dgp Added notes about controlling volume of named snd, and updated
 %               broken link to ResEdit.
 % 4/13/02   dgp Warn that the two platforms have different default sampling rate,
 %               and suggest that everyone routinely specify sampling rate to
 %               make their programs platform-independent.
-% 4/13/02	dgp Enhanced both OS9 and WIN versions so that 'DefaultRate'
+% 4/13/02   dgp Enhanced both OS9 and WIN versions so that 'DefaultRate'
 %               returns the default sampling rate in Hz.
-% 4/13/02	dgp Changed WIN code, so that sampling rate is now same on both platforms.
+% 4/13/02   dgp Changed WIN code, so that sampling rate is now same on both platforms.
 % 4/15/02   awi fixed WIN code.
 % 5/30/02   awi Added sampleSize argument and documented.
 %               SndTest would crash Matlab but the problem mysteriously vanished while editing
@@ -138,13 +156,52 @@ function err = Snd(command,signal,rate,sampleSize)
 % 9/03/12    mk Add new implementation via PsychPortAudio(), which is used
 %               by default unless user opts out. Cleanup online help by
 %               removal of obsolete and outdated information.
+% 7/20/15    mk Make commands case insensitive, white-space cleanup, try to
+%               make Snd('Open'); Snd('Close'); sequences work to avoid problems
+%               like in PTB forum message #19284 on Linux or Windows.
+% 1/19/16    mk Make more robust against failing InitializePsychSound. Fallback to sound().
+% 7/11/19    mk Allow sharing pahandle with external code / piggyback onto existing pahandle
+%               via Snd('Open', pahandle);
 
 persistent ptb_snd_oldstyle;
+persistent ptb_snd_injected;
 persistent pahandle;
 
 persistent endTime;
 if isempty(endTime)
     endTime = 0;
+    ptb_snd_injected = 0;
+end
+
+% Default return value:
+err = 0;
+
+if nargin == 0
+    error('Wrong number of arguments: see Snd.');
+end
+
+% Snd('Open', pahandle) called to inject a pahandle of an already open
+% PsychPortAudio device for sharing? If so, we piggyback onto pahandle
+% for our audio playback:
+if strcmpi(command,'Open') && nargin == 2
+    % Close previous PsychPortAudio handle if it was not injected into us:
+    if ~isempty(pahandle) && pahandle ~= signal && ~ptb_snd_injected
+        PsychPortAudio('Close', pahandle);
+    end
+
+    % Assign 2nd argument as new pahandle:
+    pahandle = signal;
+
+    % Obviously we are not in old style mode here:
+    ptb_snd_oldstyle = 0;
+
+    % Mark this pahandle as injected -- should not be closed by us ever:
+    ptb_snd_injected = 1;
+
+    endTime = 0;
+
+    fprintf('Snd(): Using PsychPortAudio via handle %i until you call Snd(''Close'');\n', pahandle);
+    return;
 end
 
 % Already defined if we shall use the new-style or old-style
@@ -156,37 +213,40 @@ if isempty(ptb_snd_oldstyle)
         % Matlab/Octave sound() function:
         ptb_snd_oldstyle = 1;
 
-        fprintf('Snd(): Using Matlab/Octave sound() function for sound output.\n');    
+        fprintf('Snd(): Using Matlab/Octave sound() function for sound output.\n');
     else
         % User wants new-style PsychPortAudio variant:
         ptb_snd_oldstyle = 0;
-        
+
         fprintf('Snd(): Initializing PsychPortAudio driver for sound output.\n');
 
         % Low-Latency preinit. Not that we'd need it, but doesn't hurt:
-        InitializePsychSound(1);        
+        try
+            InitializePsychSound(1);
+        catch
+            fprintf('Snd(): ERROR!\n');
+            ple;
+            psychlasterror('reset');
+            fprintf('Snd(): PsychPortAudio initialization failed - See error messages above. Trying to use old sound() fallback instead.\n');
+            ptb_snd_oldstyle = 1;
+        end
     end
 end
 
 % Don't use PsychPortAudio backend if already a PPA device open on Linux or
 % Windows, as that device will often have exclusive access, so we would
 % fail here:
-if isempty(pahandle) && ~ptb_snd_oldstyle && ~IsOSX && (PsychPortAudio('GetOpenDeviceCount') > 0)
+if ~(strcmpi(command,'Open') || strcmpi(command,'Quiet') || strcmpi(command,'Close')) && ...
+    isempty(pahandle) && ~ptb_snd_oldstyle && ~IsOSX && (PsychPortAudio('GetOpenDeviceCount') > 0)
     fprintf('Snd(): PsychPortAudio already in use. Using old sound() fallback instead...\n');
     ptb_snd_oldstyle = 1;
 end
 
-err=0;
-
-if nargin == 0
-    error('Wrong number of arguments: see Snd.');
-end
-
-if streq(command,'Play')
+if strcmpi(command,'Play')
     if nargin > 4
         error('Wrong number of arguments: see Snd.');
     end
-    
+
     if nargin == 4
         if isempty(sampleSize)
             sampleSize = 16;
@@ -196,19 +256,19 @@ if streq(command,'Play')
     else
         sampleSize = 16;
     end
-    
+
     if nargin < 3
         rate = [];
     end
-    
+
     if nargin < 2
         error('Wrong number of arguments: see Snd.');
     end
-    
+
     if size(signal,1) > size(signal,2)
         error('signal must be a 2 rows by n column matrix for stereo sounds.');
     end
-    
+
     if isempty(rate)
         if ptb_snd_oldstyle
             % Old MacOS-9 style default:
@@ -218,12 +278,12 @@ if streq(command,'Play')
             rate = [];
         end
     end
-    
+
     if ptb_snd_oldstyle
         % Old-Style implementation via sound() function:
 
         WaitSecs(endTime-GetSecs); % Wait until any ongoing sound is done.
-    
+
         % Octave special-case:
         if IsOctave
             if exist('sound') %#ok<EXIST>
@@ -235,7 +295,7 @@ if streq(command,'Play')
                     pkg('load','audio');
                 catch %#ok<CTCH>
                 end
-                
+
                 % Retry...
                 if exist('sound') %#ok<EXIST>
                     sound(signal',rate);
@@ -246,46 +306,57 @@ if streq(command,'Play')
         else
             sound(signal',rate,sampleSize);
         end
-        
+
         % Estimate 'endTime' for playback:
         endTime=GetSecs+length(signal)/rate;
     else
         % New-Style via PsychPortAudio:
         if ~isempty(pahandle)
             % PPA playback device already open.
-            
+
             % Wait blocking until end of its playback:
             PsychPortAudio('Stop', pahandle, 1, 1);
-            
+
             % Correct sampling rate set?
             props = PsychPortAudio('GetStatus', pahandle);
             if ~isempty(rate) && (abs(props.SampleRate - rate) > 1.0)
                 % Device sampleRate not within tolerance of 1 Hz to
-                % requested samplingrate. Close it, so it can get reopened
-                % with proper rate:
-                PsychPortAudio('Close', pahandle);
-                pahandle = [];
+                % requested samplingrate.
+                if ~ptb_snd_injected
+                    % Close it, so it can get reopened with proper rate:
+                    PsychPortAudio('Close', pahandle);
+                    pahandle = [];
+                else
+                    % Should change samplerate, but can not, as this is a shared
+                    % pahandle:
+                    fprintf('Snd(): Shared PsychPortAudio handle. Can not change sample rate from current %f Hz to %f Hz as requested!\n', ...
+                            props.SampleRate, rate);
+                end
             end
         end
-        
+
         if isempty(pahandle)
             % Be silent during driver/device init:
             oldverbosity = PsychPortAudio('Verbosity', 2);
-            
+
             % Open our own 'pahandle' sound device: Auto-Selected output
             % device [], playback only (1),
             % high-latency/low-timing-precision mode (0), at given
             % samplerate (rate), in stereo (2):
             pahandle = PsychPortAudio('Open', [], 1, 0, rate, 2);
-            
+
             % Restore standard level of verbosity:
             PsychPortAudio('Verbosity', oldverbosity);
-            
+
             if ~IsOSX
                 fprintf('Snd(): PsychPortAudio will be blocked for use by your own code until you call Snd(''Close'');\n');
                 fprintf('Snd(): If you want to use PsychPortAudio and Snd in the same session, make sure to open your\n');
-                fprintf('Snd(): stimulation sound device via calls to PsychPortAudio(''Open'', ...); *before* the first\n');
-                fprintf('Snd(): call to Snd() or any function that might use Snd(), e.g., Beeper() and the Eyelink functions.\n\n');
+                fprintf('Snd(): stimulation sound device via calls to, e.g., pahandle = PsychPortAudio(''Open'', ...);\n');
+                fprintf('Snd(): *before* the first call to Snd() or any function that might use Snd(), e.g., Beeper()\n');
+                fprintf('Snd(): or the Eyelink functions with auditory feedback. Call Snd(''Open'', pahandle) next, to\n');
+                fprintf('Snd(): share that pahandle audio device with Snd(), Beeper() et al. for optimal collaboration.\n');
+                fprintf('Snd(): Consider using PsychPortAudio(''OpenSlave'', ...); on a master device and pass that slave\n');
+                fprintf('Snd(): handle to Snd(''Open'', ...) if you want to allow Snd() to operate fully independently.\n\n');
             end
         end
 
@@ -295,18 +366,17 @@ if streq(command,'Play')
         else
             sndbuff = signal;
         end
-        
+
         % Play it:
         PsychPortAudio('FillBuffer', pahandle, sndbuff);
         PsychPortAudio('Start', pahandle, 1, 0, 1);
-        
     end
-    
-elseif streq(command,'Wait')
+
+elseif strcmpi(command,'Wait')
     if nargin>1
         error('Wrong number of arguments: see Snd.');
     end
-    
+
     if ~isempty(pahandle)
         % Wait blocking until end of playback:
         PsychPortAudio('Stop', pahandle, 1, 1);
@@ -314,12 +384,12 @@ elseif streq(command,'Wait')
         WaitSecs(endTime-GetSecs); % Wait until any ongoing sound is done.
     end
     err=0;
-    
-elseif streq(command,'IsPlaying')
+
+elseif strcmpi(command,'IsPlaying')
     if nargin>1
         error('Wrong number of arguments: see Snd.');
     end
-    
+
     if ~isempty(pahandle)
         props = PsychPortAudio('GetStatus', pahandle);
         err = props.Active;
@@ -330,21 +400,25 @@ elseif streq(command,'IsPlaying')
             err=0;
         end
     end
-    
-elseif streq(command,'Quiet') || streq(command,'Close')
+
+elseif strcmpi(command,'Quiet') || strcmpi(command,'Close')
     if nargin>1
         error('Wrong number of arguments: see Snd.');
     end
-    
+
     if ~isempty(pahandle)
         % Stop playback asap, wait for stop:
         PsychPortAudio('Stop', pahandle, 2, 1);
-        
+
         % Close command?
-        if streq(command,'Close')
-            % Close it:
-            PsychPortAudio('Close', pahandle);
+        if strcmpi(command,'Close')
+            if ~ptb_snd_injected
+                % Close it:
+                PsychPortAudio('Close', pahandle);
+            end
+
             pahandle = [];
+            ptb_snd_injected = 0;
         end
     else
         if ~IsOctave
@@ -353,12 +427,12 @@ elseif streq(command,'Quiet') || streq(command,'Close')
     end
     endTime=0;
     err=0;
-    
-elseif streq(command,'DefaultRate')
+
+elseif strcmpi(command,'DefaultRate')
     if nargin>1
         error('Wrong number of arguments: see Snd.');
     end
-    
+
     if ptb_snd_oldstyle
         % Old style - old hard-coded default:
         err = 22254.5454545454; % default sampling rate in Hz.
@@ -368,16 +442,17 @@ elseif streq(command,'DefaultRate')
             % No: Fake it - Use the most common sampling rate:
             err = 44100;
         else
-            % Yes: Query its default sampling rate:
+            % Yes: Query its current sampling rate:
             s = PsychPortAudio('GetStatus', pahandle);
-            di = PsychPortAudio('GetDevices', [], s.OutDeviceIndex);
-            err = di.DefaultSampleRate;
+            err = s.SampleRate;
         end
     end
-    
-elseif streq(command,'Open')
+
+elseif strcmpi(command,'Open')
     endTime=0;
 else
+    PsychPortAudio('Close');
+    pahandle = [];
     error(['unknown command "' command '"']);
 end
 
