@@ -63,6 +63,7 @@ function UpdatePsychtoolbox(targetdirectory, targetRevision)
 % 10/28/15 mk  32-Bit Octave-4 support for MS-Windows reestablished.
 % 04/01/16 mk  64-Bit Octave-4 support for MS-Windows established.
 % 06/01/16 mk  32-Bit Octave-4 support for MS-Windows removed.
+% 06/01/19 mk  Give automated hint about updated svn client under Matlab.
 
 % Flush all MEX files: This is needed at least on M$-Windows for SVN to
 % work if Screen et al. are still loaded.
@@ -96,6 +97,14 @@ if any(isspace(targetdirectory))
     fprintf('The targetdirectory spec contains white-space. This should work, but has not been tested extensively.\n');
 end
 
+% Check if this is 32-Bit Octave-4 on Windows, which we don't support at all:
+if isempty(strfind(computer, 'x86_64')) && ~isempty(strfind(computer, 'mingw32'))
+    fprintf('Psychtoolbox 3.0.13 and later do no longer work with 32-Bit GNU/Octave-4 on MS-Windows.\n');
+    fprintf('You need to use 64-Bit Octave-4 if you want to use Psychtoolbox with Octave on Windows.\n');
+    fprintf('DownloadPsychtoolbox() with flavor ''Psychtoolbox-3.0.12'', does support 32-Bit Octave-4 on Windows.\n');
+    error('Tried to setup on 32-Bit Octave, which is no longer supported on Windows.');
+end
+
 % Check if this is 32-Bit Matlab on Windows or Linux, which we don't support anymore:
 if (strcmp(computer, 'PCWIN') || strcmp(computer, 'GLNX86'))
     fprintf('Psychtoolbox 3.0.12 and later do no longer work with 32-Bit versions of Matlab.\n');
@@ -125,14 +134,6 @@ if strcmp(computer, 'i686-pc-mingw32')
     error('Tried to setup on Octave, which is no longer supported on MS-Windows.');
 end
 
-% Check if this is 32-Bit Octave-4 on Windows, which we don't support at all:
-if isempty(strfind(computer, 'x86_64')) && ~isempty(strfind(computer, 'mingw32'))
-    fprintf('Psychtoolbox 3.0.13 and later do no longer work with 32-Bit GNU/Octave-4 on MS-Windows.\n');
-    fprintf('You need to use 64-Bit Octave-4 if you want to use Psychtoolbox with Octave on Windows.\n');
-    fprintf('DownloadPsychtoolbox() with flavor ''Psychtoolbox-3.0.12'', does support 32-Bit Octave-4 on Windows.\n');
-    error('Tried to setup on 32-Bit Octave, which is no longer supported on Windows.');
-end
-
 if strcmp(computer,'MAC')
     fprintf('This version of Psychtoolbox is no longer supported under MacOSX on the Apple PowerPC hardware platform.\n');
     fprintf('You can get modern versions of Psychtoolbox-3 for Linux if you choose to install GNU/Linux on your PowerPC\n');
@@ -146,6 +147,7 @@ end
 IsWin = ~isempty(strfind(computer, 'PCWIN')) || ~isempty(strfind(computer, '-w64-mingw32'));
 IsOSX = ~isempty(strfind(computer, 'MAC')) || ~isempty(strfind(computer, 'apple-darwin'));
 IsLinux = strcmp(computer,'GLNX86') || strcmp(computer,'GLNXA64') || ~isempty(strfind(computer, 'linux-gnu'));
+IsOctave = isempty (ver('matlab'));
 
 if ~IsWin && ~IsOSX && ~IsLinux
     os = computer;
@@ -184,18 +186,35 @@ fprintf('About to update your working copy of the OpenGL-based Psychtoolbox-3.\n
 updatecommand=[svnpath 'svn update '  targetRevision ' ' strcat('"',targetdirectory,'"') ];
 fprintf('Will execute the following update command:\n');
 fprintf('%s\n', updatecommand);
-if IsOSX || IsLinux
-    err=system(updatecommand);
-    result = 'For reason, see output above.';
+
+if IsOctave
+    % Octave's system() command (and its dos() and unix() wrappers around system())
+    % does not print any live output from the checkoutcommand if return of the 'result'
+    % string is requested. We want some live feedback, so users get some feeling of
+    % download progress and don't get confused if the thing is just sitting there for
+    % minutes without giving feedback. Therefore don't request 'result':
+    err = system(updatecommand);
+    result = 'For reasons and troubleshooting, read the output above and all followup messages!';
 else
-    % MK: TODO: Check if this is still needed on >= R2007a on Windows?
-    % I think it was only for R11 on Windows.
-    [err, result]=dos(updatecommand, '-echo');
+    % Matlab's system() command can provide live feedback from 'checkoutcommand'
+    % during svn checkout and return the same output in 'result' at the end, so
+    % we can get 'result' for parsing:
+    [err, result] = system(updatecommand, '-echo');
 end
 
 if err
-    fprintf('Sorry. The update command failed:\n');
+    fprintf('Sorry. The update command failed with error code %d:\n', err);
     fprintf('%s\n', result);
+
+    if IsOctave
+        fprintf('If the error output above contains the text ''SSL handshake failed: SSL error: tlsv1 alert protocol version''\n');
+        fprintf('then your svn command line client is too old. Install a more recent Subversion command line client.\n');
+    else
+        if ~isempty(strfind(result, 'tlsv1 alert protocol version'))
+            fprintf('Seems your svn command line client is too old. Install a more recent Subversion command line client.\n');
+        end
+    end
+
     error('Update failed.');
 end
 fprintf('Success!\n\n');
